@@ -1,10 +1,5 @@
 package Carp::Patch::Config;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-19'; # DATE
-our $DIST = 'Carp-Patch-Config'; # DIST
-our $VERSION = '0.006'; # VERSION
-
 use 5.010001;
 use strict;
 no warnings;
@@ -12,6 +7,11 @@ no warnings;
 use Module::Patch qw();
 use base qw(Module::Patch);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-02-06'; # DATE
+our $DIST = 'Carp-Patch-Config'; # DIST
+our $VERSION = '0.007'; # VERSION
+
 my @oldvals;
 our %config;
 
@@ -58,7 +58,7 @@ _
             },
         },
         after_patch => sub {
-            no strict 'refs';
+            no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
             no warnings 'numeric';
             my $oldvals = {};
             for my $name (keys %config) {
@@ -79,7 +79,7 @@ _
             push @oldvals, $oldvals;
         },
         after_unpatch => sub {
-            no strict 'refs';
+            no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
             my $oldvals = shift @oldvals or return;
             for (keys %$oldvals) {
                 ${"Carp::$_"} = $oldvals->{$_};
@@ -103,7 +103,7 @@ Carp::Patch::Config - Set some Carp variables
 
 =head1 VERSION
 
-This document describes version 0.006 of Carp::Patch::Config (from Perl distribution Carp-Patch-Config), released on 2020-06-19.
+This document describes version 0.007 of Carp::Patch::Config (from Perl distribution Carp-Patch-Config), released on 2022-02-06.
 
 =head1 SYNOPSIS
 
@@ -167,14 +167,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Carp-Patch
 
 Source repository is at L<https://github.com/perlancar/perl-Carp-Patch-Config>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Carp-Patch-Config>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Module::Patch>
@@ -183,15 +175,42 @@ L<Carp>
 
 L<Devel::Confess>
 
+L<Carp::Patch::Verbose>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Carp-Patch-Config>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
